@@ -2,9 +2,12 @@
 #define SRC_NODE_VERSION_H_
 
 #define NODE_MAJOR_VERSION 4
-#define NODE_MINOR_VERSION 1
+#define NODE_MINOR_VERSION 6
 #define NODE_PATCH_VERSION 1
 
+#define NODE_VERSION_IS_LTS 1
+#define NODE_VERSION_LTS_CODENAME "Argon"
+
 #define NODE_VERSION_IS_RELEASE 1
 
 #ifndef NODE_STRINGIFY
@@ -18,12 +21,21 @@
 # else
 #  define NODE_TAG "-pre"
 # endif
+#else
+// NODE_TAG is passed without quotes when rc.exe is run from msbuild
+# define NODE_EXE_VERSION NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
+                          NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
+                          NODE_STRINGIFY(NODE_PATCH_VERSION)     \
+                          NODE_STRINGIFY(NODE_TAG)
 #endif
 
 # define NODE_VERSION_STRING  NODE_STRINGIFY(NODE_MAJOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_MINOR_VERSION) "." \
                               NODE_STRINGIFY(NODE_PATCH_VERSION)     \
                               NODE_TAG
+#ifndef NODE_EXE_VERSION
+# define NODE_EXE_VERSION NODE_VERSION_STRING
+#endif
 
 #define NODE_VERSION "v" NODE_VERSION_STRING
 
@@ -42,4 +54,4 @@
  */
 #define NODE_MODULE_VERSION 46 /* Node.js v4.0.0 */
 
-#endif  /* SRC_NODE_VERSION_H_ */
+#endif  // SRC_NODE_VERSION_H_
